@@ -26,6 +26,7 @@ from argparse import (ArgumentDefaultsHelpFormatter,
                       ArgumentParser,
                       Namespace,
                       _ArgumentGroup)
+from distutils.util import strtobool
 from functools import lru_cache
 from types import TracebackType
 from typing import (IO,
@@ -83,7 +84,10 @@ from toil.version import dockerRegistry, dockerTag, version
 if TYPE_CHECKING:
     from toil.batchSystems.abstractBatchSystem import AbstractBatchSystem
     from toil.batchSystems.options import OptionSetter
-    from toil.job import Job, JobDescription, TemporaryID, AcceleratorRequirement
+    from toil.job import (AcceleratorRequirement,
+                          Job,
+                          JobDescription,
+                          TemporaryID)
     from toil.jobStores.abstractJobStore import AbstractJobStore
     from toil.provisioners.abstractProvisioner import AbstractProvisioner
     from toil.resource import ModuleDescriptor
@@ -140,7 +144,7 @@ class Config:
         set_batchsystem_config_defaults(self)
 
         # File store options
-        self.disableCaching: bool = False
+        self.caching: Optional[bool] = None
         self.linkImports: bool = True
         self.moveExports: bool = False
 
@@ -152,14 +156,14 @@ class Config:
         self.targetTime: float = defaultTargetTime
         self.betaInertia: float = 0.1
         self.scaleInterval: int = 60
-        self.preemptableCompensation: float = 0.0
+        self.preemptibleCompensation: float = 0.0
         self.nodeStorage: int = 50
         self.nodeStorageOverrides: List[str] = []
         self.metrics: bool = False
         self.assume_zero_overhead: bool = False
 
         # Parameters to limit service jobs, so preventing deadlock scheduling scenarios
-        self.maxPreemptableServiceJobs: int = sys.maxsize
+        self.maxPreemptibleServiceJobs: int = sys.maxsize
         self.maxServiceJobs: int = sys.maxsize
         self.deadlockWait: Union[float, int] = 60  # Number of seconds we must be stuck with all services before declaring a deadlock
         self.deadlockCheckInterval: Union[float, int] = 30  # Minimum polling delay for deadlocks
@@ -168,7 +172,7 @@ class Config:
         self.defaultMemory: int = 2147483648
         self.defaultCores: Union[float, int] = 1
         self.defaultDisk: int = 2147483648
-        self.defaultPreemptable: bool = False
+        self.defaultPreemptible: bool = False
         # TODO: These names are generated programmatically in
         # Requirer._fetchRequirement so we can't use snake_case until we fix
         # that (and add compatibility getters/setters?)
@@ -179,7 +183,7 @@ class Config:
 
         # Retrying/rescuing jobs
         self.retryCount: int = 1
-        self.enableUnlimitedPreemptableRetries: bool = False
+        self.enableUnlimitedPreemptibleRetries: bool = False
         self.doubleMem: bool = False
         self.maxJobDuration: int = sys.maxsize
         self.rescueJobsFrequency: int = 60
@@ -333,7 +337,7 @@ class Config:
         # File store options
         set_option("linkImports", bool, default=True)
         set_option("moveExports", bool, default=False)
-        set_option("disableCaching", bool, default=False)
+        set_option("caching", bool, default=None)
 
         # Autoscaling options
         set_option("provisioner")
@@ -349,9 +353,9 @@ class Config:
         set_option("scaleInterval", float)
         set_option("metrics")
         set_option("assume_zero_overhead")
-        set_option("preemptableCompensation", float)
-        if not 0.0 <= self.preemptableCompensation <= 1.0:
-            raise RuntimeError(f'preemptableCompensation ({self.preemptableCompensation}) must be between 0.0 and 1.0!')
+        set_option("preemptibleCompensation", float)
+        if not 0.0 <= self.preemptibleCompensation <= 1.0:
+            raise RuntimeError(f'preemptibleCompensation ({self.preemptibleCompensation}) must be between 0.0 and 1.0!')
         set_option("nodeStorage", int)
 
         def check_nodestoreage_overrides(overrides: List[str]) -> bool:
@@ -368,7 +372,7 @@ class Config:
 
         # Parameters to limit service jobs / detect deadlocks
         set_option("maxServiceJobs", int)
-        set_option("maxPreemptableServiceJobs", int)
+        set_option("maxPreemptibleServiceJobs", int)
         set_option("deadlockWait", int)
         set_option("deadlockCheckInterval", int)
 
@@ -381,11 +385,11 @@ class Config:
         set_option("maxCores", int, iC(1))
         set_option("maxMemory", h2b, iC(1))
         set_option("maxDisk", h2b, iC(1))
-        set_option("defaultPreemptable")
+        set_option("defaultPreemptible")
 
         # Retrying/rescuing jobs
         set_option("retryCount", int, iC(1))
-        set_option("enableUnlimitedPreemptableRetries")
+        set_option("enableUnlimitedPreemptibleRetries")
         set_option("doubleMem")
         set_option("maxJobDuration", int, iC(1))
         set_option("rescueJobsFrequency", int, iC(1))
@@ -563,10 +567,12 @@ def addOptions(parser: ArgumentParser, config: Optional[Config] = None) -> None:
     move_exports.add_argument("--moveExports", dest="moveExports", action='store_true', help=move_exports_help)
     move_exports.add_argument("--noMoveExports", dest="moveExports", action='store_false', help=move_exports_help)
     move_exports.set_defaults(moveExports=False)
-    file_store_options.add_argument('--disableCaching', dest='disableCaching', action='store_true',
-                                    default=False,
-                                    help='Disables caching in the file store. This flag must be set to use '
-                                         'a batch system that does not support cleanup, such as Parasol.')
+
+    caching = file_store_options.add_mutually_exclusive_group()
+    caching_help = ("Enable or disable caching for your workflow, specifying this overrides default from job store")
+    caching.add_argument('--disableCaching', dest='caching', action='store_false', help=caching_help)
+    caching.add_argument('--caching', dest='caching', type=lambda val: bool(strtobool(val)), help=caching_help)
+    caching.set_defaults(caching=None)
 
     # Auto scaling options
     autoscaling_options = parser.add_argument_group(
@@ -584,9 +590,9 @@ def addOptions(parser: ArgumentParser, config: Optional[Config] = None) -> None:
     autoscaling_options.add_argument('--nodeTypes', default=None,
                                      help="Specifies a list of comma-separated node types, each of which is "
                                           "composed of slash-separated instance types, and an optional spot "
-                                          "bid set off by a colon, making the node type preemptable. Instance "
+                                          "bid set off by a colon, making the node type preemptible. Instance "
                                           "types may appear in multiple node types, and the same node type "
-                                          "may appear as both preemptable and non-preemptable.\n"
+                                          "may appear as both preemptible and non-preemptible.\n"
                                           "Valid argument specifying two node types:\n"
                                           "\tc5.4xlarge/c5a.4xlarge:0.42,t2.large\n"
                                           "Node types:\n"
@@ -620,14 +626,14 @@ def addOptions(parser: ArgumentParser, config: Optional[Config] = None) -> None:
     autoscaling_options.add_argument("--scaleInterval", dest="scaleInterval", default=None,
                                      help=f"The interval (seconds) between assessing if the scale of "
                                           f"the cluster needs to change. default={config.scaleInterval}")
-    autoscaling_options.add_argument("--preemptableCompensation", dest="preemptableCompensation", default=None,
-                                     help=f"The preference of the autoscaler to replace preemptable nodes with "
-                                          f"non-preemptable nodes, when preemptable nodes cannot be started for some "
-                                          f"reason. Defaults to {config.preemptableCompensation}. This value must be "
+    autoscaling_options.add_argument("--preemptibleCompensation", "--preemptableCompensation", dest="preemptibleCompensation", default=None,
+                                     help=f"The preference of the autoscaler to replace preemptible nodes with "
+                                          f"non-preemptible nodes, when preemptible nodes cannot be started for some "
+                                          f"reason. Defaults to {config.preemptibleCompensation}. This value must be "
                                           f"between 0.0 and 1.0, inclusive.  A value of 0.0 disables such "
-                                          f"compensation, a value of 0.5 compensates two missing preemptable nodes "
-                                          f"with a non-preemptable one. A value of 1.0 replaces every missing "
-                                          f"pre-emptable node with a non-preemptable one.")
+                                          f"compensation, a value of 0.5 compensates two missing preemptible nodes "
+                                          f"with a non-preemptible one. A value of 1.0 replaces every missing "
+                                          f"pre-emptable node with a non-preemptible one.")
     autoscaling_options.add_argument("--nodeStorage", dest="nodeStorage", default=50,
                                      help="Specify the size of the root volume of worker nodes when they are launched "
                                           "in gigabytes. You may want to set this if your jobs require a lot of disk "
@@ -653,12 +659,12 @@ def addOptions(parser: ArgumentParser, config: Optional[Config] = None) -> None:
         )
         service_options.add_argument("--maxServiceJobs", dest="maxServiceJobs", default=None, type=int,
                                      help=f"The maximum number of service jobs that can be run concurrently, "
-                                          f"excluding service jobs running on preemptable nodes.  "
+                                          f"excluding service jobs running on preemptible nodes.  "
                                           f"default={config.maxServiceJobs}")
-        service_options.add_argument("--maxPreemptableServiceJobs", dest="maxPreemptableServiceJobs", default=None,
+        service_options.add_argument("--maxPreemptibleServiceJobs", dest="maxPreemptibleServiceJobs", default=None,
                                      type=int,
                                      help=f"The maximum number of service jobs that can run concurrently on "
-                                          f"preemptable nodes.  default={config.maxPreemptableServiceJobs}")
+                                          f"preemptible nodes.  default={config.maxPreemptibleServiceJobs}")
         service_options.add_argument("--deadlockWait", dest="deadlockWait", default=None, type=int,
                                      help=f"Time, in seconds, to tolerate the workflow running only the same service "
                                           f"jobs, with no jobs to use them, before declaring the workflow to be "
@@ -695,9 +701,9 @@ def addOptions(parser: ArgumentParser, config: Optional[Config] = None) -> None:
                                   help=resource_help_msg.format('default', 'disk', disk_mem_note, bytes2human(config.defaultDisk)))
     resource_options.add_argument('--defaultAccelerators', dest='defaultAccelerators', default=None, metavar='ACCELERATOR[,ACCELERATOR...]',
                                   help=resource_help_msg.format('default', 'accelerators', accelerators_note, config.defaultAccelerators))
-    resource_options.add_argument('--defaultPreemptable', dest='defaultPreemptable', metavar='BOOL',
+    resource_options.add_argument('--defaultPreemptible', '--defaultPreemptable', dest='defaultPreemptible', metavar='BOOL',
                                   type=bool, nargs='?', const=True, default=False,
-                                  help='Make all jobs able to run on preemptable (spot) nodes by default.')
+                                  help='Make all jobs able to run on preemptible (spot) nodes by default.')
     resource_options.add_argument('--maxCores', dest='maxCores', default=None, metavar='INT',
                                   help=resource_help_msg.format('max', 'cpu', cpu_note, str(config.maxCores)))
     resource_options.add_argument('--maxMemory', dest='maxMemory', default=None, metavar='INT',
@@ -713,9 +719,9 @@ def addOptions(parser: ArgumentParser, config: Optional[Config] = None) -> None:
     job_options.add_argument("--retryCount", dest="retryCount", default=None,
                              help=f"Number of times to retry a failing job before giving up and "
                                   f"labeling job failed. default={config.retryCount}")
-    job_options.add_argument("--enableUnlimitedPreemptableRetries", dest="enableUnlimitedPreemptableRetries",
+    job_options.add_argument("--enableUnlimitedPreemptibleRetries", "--enableUnlimitedPreemptableRetries", dest="enableUnlimitedPreemptibleRetries",
                              action='store_true', default=False,
-                             help="If set, preemptable failures (or any failure due to an instance getting "
+                             help="If set, preemptible failures (or any failure due to an instance getting "
                                   "unexpectedly terminated) will not count towards job failures and --retryCount.")
     job_options.add_argument("--doubleMem", dest="doubleMem", action='store_true', default=False,
                              help="If set, batch jobs which die to reaching memory limit on batch schedulers "
@@ -919,6 +925,11 @@ class Toil(ContextManager["Toil"]):
         config = Config()
         config.setOptions(self.options)
         jobStore = self.getJobStore(config.jobStore)
+        if config.caching is None:
+            config.caching = jobStore.default_caching()
+            #Set the caching option because it wasn't set originally, resuming jobstore rebuilds config from CLI options
+            self.options.caching = config.caching
+
         if not config.restart:
             config.workflowAttemptNumber = 0
             jobStore.initialize(config)
@@ -1135,10 +1146,11 @@ class Toil(ContextManager["Toil"]):
             raise RuntimeError(f'Unrecognized batch system: {config.batchSystem}  '
                                f'(choose from: {BATCH_SYSTEM_FACTORY_REGISTRY.keys()})')
 
-        if not config.disableCaching and not batch_system.supportsWorkerCleanup():
+        if config.caching and not batch_system.supportsWorkerCleanup():
             raise RuntimeError(f'{config.batchSystem} currently does not support shared caching, because it '
-                               'does not support cleaning up a worker after the last job finishes. Set the '
-                               '--disableCaching flag if you want to use this batch system.')
+                               'does not support cleaning up a worker after the last job finishes. Set '
+                               '--caching=false')
+
         logger.debug('Using the %s' % re.sub("([a-z])([A-Z])", r"\g<1> \g<2>", batch_system.__name__).lower())
 
         return batch_system(**kwargs)
@@ -1294,7 +1306,7 @@ class Toil(ContextManager["Toil"]):
         """Download all jobs in the current job store into self.jobCache."""
         logger.debug('Caching all jobs in job store')
         self._jobCache = {jobDesc.jobStoreID: jobDesc for jobDesc in self._jobStore.jobs()}
-        logger.debug('{} jobs downloaded.'.format(len(self._jobCache)))
+        logger.debug(f'{len(self._jobCache)} jobs downloaded.')
 
     def _cacheJob(self, job: "JobDescription") -> None:
         """
@@ -1532,9 +1544,10 @@ class ToilMetrics:
 
         # On single machine, launch a node exporter instance to monitor CPU/RAM usage.
         # On AWS this is handled by the EC2 init script
+        self.nodeExporterProc: Optional[subprocess.Popen[bytes]] = None
         if not provisioner:
             try:
-                self.nodeExporterProc: Optional[subprocess.Popen[bytes]] = subprocess.Popen(
+                self.nodeExporterProc = subprocess.Popen(
                     ["docker", "run",
                      "--rm",
                      "--net=host",
@@ -1549,9 +1562,9 @@ class ToilMetrics:
                      "^/(sys|proc|dev|host|etc)($|/)"])
             except subprocess.CalledProcessError:
                 logger.warning("Couldn't start node exporter, won't get RAM and CPU usage for dashboard.")
-                self.nodeExporterProc = None
             except KeyboardInterrupt:
-                self.nodeExporterProc.terminate()  # type: ignore[union-attr]
+                if self.nodeExporterProc is not None:
+                    self.nodeExporterProc.terminate()
 
         # When messages come in on the message bus, call our methods.
         # TODO: Just annotate the methods with some kind of @listener and get
@@ -1661,10 +1674,14 @@ class ToilMetrics:
         self.log("completed_job %s" % m.job_type)
 
     def shutdown(self) -> None:
-        if self.mtailProc:
+        if self.mtailProc is not None:
+            logger.debug('Stopping mtail')
             self.mtailProc.kill()
-        if self.nodeExporterProc:
+            logger.debug('Stopped mtail')
+        if self.nodeExporterProc is not None:
+            logger.debug('Stopping node exporter')
             self.nodeExporterProc.kill()
+            logger.debug('Stopped node exporter')
         self._listeners = []
 
 
@@ -1734,6 +1751,7 @@ def parse_accelerator_list(specs: Optional[str]) -> List['AcceleratorRequirement
         return []
     # Otherwise parse each requirement.
     from toil.job import AcceleratorRequirement
+
     # TODO: MyPy doesn't think AcceleratorRequirement has a parse()
     parser: Callable[[str], AcceleratorRequirement] = AcceleratorRequirement.parse  # type: ignore
     return [parser(r) for r in specs.split(',')]
