@@ -11,7 +11,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Optional, Dict
+from typing import Any, Dict, Optional
+
 from gunicorn.app.base import BaseApplication  # type: ignore
 
 
